@@ -1,11 +1,10 @@
 /* apt-dater - terminal-based remote package update manager
  *
  * Authors:
- *   Andre Ellguth <ellguth@ibh.de>
  *   Thomas Liske <liske@ibh.de>
  *
  * Copyright Holder:
- *   2008-2012 (C) IBH IT-Service GmbH [http://www.ibh.de/apt-dater/]
+ *   2008-2015 (C) IBH IT-Service GmbH [https://www.ibh.de/apt-dater/]
  *
  * License:
  *   This program is free software; you can redistribute it and/or modify
@@ -39,6 +38,7 @@
 
 #include <glib.h>
 #include <glib/gstdio.h>
+#include <gio/gio.h>
 
 #include "../config.h"
 #include "../include/adproto.h"
@@ -57,7 +57,6 @@
 #define INPUT_MAX 4096
 #define BUF_MAX_LEN 256
 #define PROG_NAME PACKAGE
-#define CFGFILENAME "apt-dater.conf"
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -90,8 +89,14 @@ typedef struct _cfgfile {
  etype _type;
 #endif
  gchar *hostsfile;
+#ifdef FEAT_TMUX
+ gchar *tmuxconffile;
+ gchar *tmuxsockpath;
+#else
  gchar *screenrcfile;
  gchar *screentitle;
+#endif
+ mode_t umask;
  gchar *statsdir;
  gchar *plugindir;
  gchar *ssh_cmd;
@@ -110,6 +115,7 @@ typedef struct _cfgfile {
 #ifdef FEAT_HISTORY
  gboolean record_history;
  gchar *history_errpattern;
+ gchar *history_dir;
 #endif
  gchar **colors;
 #ifdef FEAT_TCLFILTER
@@ -145,6 +151,7 @@ typedef struct _session {
 #endif
   gint pid;
   struct stat st;
+  gboolean attached;
 } SessNode;
 
 typedef enum {
@@ -166,12 +173,13 @@ typedef enum {
 #define HOST_STATUS_PKGKEPTBACK       2
 #define HOST_STATUS_PKGEXTRA          4
 #define HOST_STATUS_PKGBROKEN         8
-#define HOST_STATUS_KERNELNOTMATCH   16
-#define HOST_STATUS_KERNELSELFBUILD  32
-#define HOST_STATUS_VIRTUALIZED      64
-#define HOST_STATUS_LOCKED          128
+#define HOST_STATUS_KERNELUNKNOWN    16
+#define HOST_STATUS_KERNELABIUPGR    32
+#define HOST_STATUS_KERNELVERUPGR    64
+#define HOST_STATUS_VIRTUALIZED     128
+#define HOST_STATUS_LOCKED          256
 #ifdef FEAT_CLUSTERS
-#define HOST_STATUS_CLUSTERED       256
+#define HOST_STATUS_CLUSTERED       512
 #endif
 
 #define HOST_FORBID_REFRESH           1
@@ -189,9 +197,11 @@ typedef struct _hostnode {
  etype _type;
 #endif
  gchar     *hostname;
+ gchar     *comment;
  gchar     *group;
  gchar     *type;
  gchar     *ssh_user;
+ gchar     *ssh_host;
  gint      ssh_port;
 #ifdef FEAT_AUTOREF
  time_t    last_upd;
@@ -205,6 +215,8 @@ typedef struct _hostnode {
  gboolean  parse_result;
  gint      hist_ts;
 #endif
+ GFileMonitor *mon_ttymux;
+ GFileMonitor *mon_stats;
  Category  category;
  GList     *packages;
  gint      nupdates;
@@ -215,6 +227,7 @@ typedef struct _hostnode {
  gint      fdlock;
  FILE      *fpstat;
  gchar     *statsfile;
+ gchar     *statstmpf;
  gchar     *lsb_distributor;
  gchar     *lsb_release;
  gchar     *lsb_codename;
@@ -227,6 +240,7 @@ typedef struct _hostnode {
  gint      forbid;
  gboolean  tagged;
  gchar     uuid[UUID_STRLEN+1];
+ gint      nrkstate;
 #ifdef FEAT_CLUSTERS
  GList     *clusters;
 #endif
